# Welcome
Please find the full documentation on [ReadTheDocs](https://baangt.readthedocs.io)

# Further reading:
Latest news on http://baangt.org for community edition and http://baangt.com for corporate environments.